==> neca-2.1.1.tar.gz: neca-2.1.1/README.md <==
# NECA - the Successor of ECA (Event-Condition-Action)
NECA is a simple Python library that allows you to create event-driven applications. It is inspired by the [ECA (Event-Condition-Action) paradigm](https://en.wikipedia.org/wiki/Event_condition_action). NECA is a successor of [ECA](https://github.com/utwente-db/eca) and is built on top of [Flask](https://flask.palletsprojects.com/en/2.0.x/).

NECA is specialized for creating web dashboards. It allows you to easily create a web server with a dashboard that can be updated real-time. It also allows you to easily add new functionality to your dashboard.

## Features
- Event-driven programming
- Basic building blocks for creating web dashboards
- Easy to use
- Easy to extend
- Easy integration with external data sources

## Installation
you can install neca using pip:
```bash
pip install neca
```

## Creating a new project
use the neca commandline tool to create a new project:
```bash
neca create [project name]
```

## Running your newly created project
to run your project, simply execute the main python file in the generated project folder:
```bash
python main.py
```

## Tutorials
If you want to learn about the neca framework in an interactive way, you can check out the tutorials. 
you can load a tutorial by creating a new project with a tutorial template. Inside these templates there's a README.md file that explains the tutorial content and has some small exercises to help you learn. To open this file in visual studio code, right click on the file and select "Open Preview".

## Documentation
You can find the documentation [here](https://github.com/NiekAukes/eca2/wiki).

## Demos
You can instantiate a demo with the neca commandline tool:
```bash
neca demo [demo name]
```
leave the demo name empty to see a list of available demos.

==> neca-2.1.13.tar.gz: neca-2.1.13/README.md <==
# NECA - the Successor of ECA (Event-Condition-Action)
NECA is a simple Python library that allows you to create event-driven applications. It is inspired by the [ECA (Event-Condition-Action) paradigm](https://en.wikipedia.org/wiki/Event_condition_action). NECA is a successor of [ECA](https://github.com/utwente-db/eca) and is built on top of [Flask](https://flask.palletsprojects.com/en/2.0.x/).

NECA is specialized for creating web dashboards. It allows you to easily create a web server with a dashboard that can be updated real-time. It also allows you to easily add new functionality to your dashboard.

## Features
- Event-driven programming
- Basic building blocks for creating web dashboards
- Easy to use
- Easy to extend
- Easy integration with external data sources

## Installation
you can install neca using pip:
```bash
pip install neca
```

## Creating a new project
use the neca commandline tool to create a new project:
```bash
neca [folder name]
```

## Running your newly created project
to run your project, simply execute the main python file in the generated project folder:
```bash
python main.py
```

## Tutorials
If you want to learn about the neca framework in an interactive way, you can check out the tutorials. 
you can load a tutorial by creating a new project with a tutorial template. Inside these templates there's a README.md file that explains the tutorial content and has some small exercises to help you learn. To open this file in visual studio code, right click on the file and select "Open Preview".

You can also view the tutorials in the Wiki:
- [Tutorial 1 - the Event System](https://github.com/NiekAukes/eca2/wiki/Tutorial-1)
- [Tutorial 2 - creating your first block](https://github.com/NiekAukes/eca2/wiki/Tutorial-2)

## Documentation
You can find the documentation [here](https://github.com/NiekAukes/eca2/wiki).

## Demos
You can instantiate a demo with the neca commandline tool and choosing an example from the list
```bash
neca [folder name]
```
